import { PropType } from 'vue';
declare const CDateRangePicker: import("vue").DefineComponent<{
    /**
     * The number of calendars that render on desktop devices.
     */
    calendars: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * Default date of the component
     */
    calendarDate: {
        type: (StringConstructor | DateConstructor)[];
    };
    /**
     * Toggle visibility or set the content of cancel button.
     */
    cancelButton: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    /**
     * Sets the color context of the cancel button to one of CoreUI’s themed colors.
     *
     * @values 'primary', 'secondary', 'success', 'danger', 'warning', 'info', 'dark', 'light'
     */
    cancelButtonColor: {
        default: string;
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Size the cancel button small or large.
     *
     * @values 'sm', 'lg'
     */
    cancelButtonSize: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Set the cancel button variant to an outlined button or a ghost button.
     *
     * @values 'ghost', 'outline'
     */
    cancelButtonVariant: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Toggle visibility of the cleaner button.
     */
    cleaner: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Toggle visibility or set the content of confirm button.
     */
    confirmButton: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    /**
     * Sets the color context of the confirm button to one of CoreUI’s themed colors.
     *
     * @values 'primary', 'secondary', 'success', 'danger', 'warning', 'info', 'dark', 'light'
     */
    confirmButtonColor: {
        default: string;
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Size the confirm button small or large.
     *
     * @values 'sm', 'lg'
     */
    confirmButtonSize: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Set the confirm button variant to an outlined button or a ghost button.
     *
     * @values 'ghost', 'outline'
     */
    confirmButtonVariant: {
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Toggle the disabled state for the component.
     */
    disabled: BooleanConstructor;
    /**
     * Specify the list of dates that cannot be selected.
     */
    disabledDates: {
        type: PropType<Date[] | Date[][]>;
    };
    /**
     * Initial selected to date (range).
     */
    endDate: {
        type: (StringConstructor | DateConstructor)[];
        required: false;
    };
    /**
     * Sets the day of start week.
     * - 0 - Sunday,
     * - 1 - Monday,
     * - 2 - Tuesday,
     * - 3 - Wednesday,
     * - 4 - Thursday,
     * - 5 - Friday,
     * - 6 - Saturday,
     */
    firstDayOfWeek: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * Set date format.
     * We use date-fns to format dates. Visit https://date-fns.org/v2.28.0/docs/format to check accepted patterns.
     */
    format: StringConstructor;
    /**
     * Toggle visibility of footer element or set the content of footer.
     */
    footer: BooleanConstructor;
    /**
     * The id global attribute defines an identifier (ID) that must be unique in the whole document.
     *
     * The name attributes for input elements are generated based on the `id` property:
     * - {id}-start-date
     * - {id}-end-date
     */
    id: StringConstructor;
    /**
     * Toggle visibility or set the content of the input indicator.
     */
    indicator: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Toggle the readonly state for the component.
     */
    inputReadOnly: BooleanConstructor;
    /**
     * Sets the default locale for components. If not set, it is inherited from the navigator.language.
     */
    locale: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Max selectable date.
     */
    maxDate: {
        type: (StringConstructor | DateConstructor)[];
    };
    /**
     * Min selectable date.
     */
    minDate: {
        type: (StringConstructor | DateConstructor)[];
    };
    /**
     * Show arrows navigation.
     */
    navigation: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Specifies a short hint that is visible in the input.
     */
    placeholder: {
        type: PropType<String | String[]>;
        default: () => string[];
    };
    /**
     * @ignore
     */
    range: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Predefined date ranges the user can select from.
     */
    ranges: ObjectConstructor;
    /**
     * Toggle select mode between start and end date.
     */
    selectEndDate: BooleanConstructor;
    /**
     * Default icon or character character that separates two dates.
     */
    separator: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Size the component small or large.
     *
     * @values 'sm', 'lg'
     */
    size: {
        type: StringConstructor;
        required: false;
        validator: (value: string) => boolean;
    };
    /**
     * Initial selected date.
     */
    startDate: {
        type: (StringConstructor | DateConstructor)[];
    };
    /**
     * Provide an additional time selection by adding select boxes to choose times.
     */
    timepicker: BooleanConstructor;
    /**
     * Toggle visibility or set the content of today button.
     */
    todayButton: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    /**
     * Sets the color context of the today button to one of CoreUI’s themed colors.
     *
     * @values 'primary', 'secondary', 'success', 'danger', 'warning', 'info', 'dark', 'light'
     */
    todayButtonColor: {
        default: string;
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Size the today button small or large.
     *
     * @values 'sm', 'lg'
     */
    todayButtonSize: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Set the today button variant to an outlined button or a ghost button.
     *
     * @values 'ghost', 'outline'
     */
    todayButtonVariant: {
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Set length or format of day name.
     *
     * @type  number | 'long' | 'narrow' | 'short'
     */
    weekdayFormat: {
        type: (NumberConstructor | StringConstructor)[];
        default: number;
        validator: (value: string | number) => boolean;
    };
}, () => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, ("hide" | "show" | "start-date-change" | "end-date-change")[], "hide" | "show" | "start-date-change" | "end-date-change", import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<import("vue").ExtractPropTypes<{
    /**
     * The number of calendars that render on desktop devices.
     */
    calendars: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * Default date of the component
     */
    calendarDate: {
        type: (StringConstructor | DateConstructor)[];
    };
    /**
     * Toggle visibility or set the content of cancel button.
     */
    cancelButton: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    /**
     * Sets the color context of the cancel button to one of CoreUI’s themed colors.
     *
     * @values 'primary', 'secondary', 'success', 'danger', 'warning', 'info', 'dark', 'light'
     */
    cancelButtonColor: {
        default: string;
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Size the cancel button small or large.
     *
     * @values 'sm', 'lg'
     */
    cancelButtonSize: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Set the cancel button variant to an outlined button or a ghost button.
     *
     * @values 'ghost', 'outline'
     */
    cancelButtonVariant: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Toggle visibility of the cleaner button.
     */
    cleaner: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Toggle visibility or set the content of confirm button.
     */
    confirmButton: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    /**
     * Sets the color context of the confirm button to one of CoreUI’s themed colors.
     *
     * @values 'primary', 'secondary', 'success', 'danger', 'warning', 'info', 'dark', 'light'
     */
    confirmButtonColor: {
        default: string;
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Size the confirm button small or large.
     *
     * @values 'sm', 'lg'
     */
    confirmButtonSize: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Set the confirm button variant to an outlined button or a ghost button.
     *
     * @values 'ghost', 'outline'
     */
    confirmButtonVariant: {
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Toggle the disabled state for the component.
     */
    disabled: BooleanConstructor;
    /**
     * Specify the list of dates that cannot be selected.
     */
    disabledDates: {
        type: PropType<Date[] | Date[][]>;
    };
    /**
     * Initial selected to date (range).
     */
    endDate: {
        type: (StringConstructor | DateConstructor)[];
        required: false;
    };
    /**
     * Sets the day of start week.
     * - 0 - Sunday,
     * - 1 - Monday,
     * - 2 - Tuesday,
     * - 3 - Wednesday,
     * - 4 - Thursday,
     * - 5 - Friday,
     * - 6 - Saturday,
     */
    firstDayOfWeek: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * Set date format.
     * We use date-fns to format dates. Visit https://date-fns.org/v2.28.0/docs/format to check accepted patterns.
     */
    format: StringConstructor;
    /**
     * Toggle visibility of footer element or set the content of footer.
     */
    footer: BooleanConstructor;
    /**
     * The id global attribute defines an identifier (ID) that must be unique in the whole document.
     *
     * The name attributes for input elements are generated based on the `id` property:
     * - {id}-start-date
     * - {id}-end-date
     */
    id: StringConstructor;
    /**
     * Toggle visibility or set the content of the input indicator.
     */
    indicator: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Toggle the readonly state for the component.
     */
    inputReadOnly: BooleanConstructor;
    /**
     * Sets the default locale for components. If not set, it is inherited from the navigator.language.
     */
    locale: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Max selectable date.
     */
    maxDate: {
        type: (StringConstructor | DateConstructor)[];
    };
    /**
     * Min selectable date.
     */
    minDate: {
        type: (StringConstructor | DateConstructor)[];
    };
    /**
     * Show arrows navigation.
     */
    navigation: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Specifies a short hint that is visible in the input.
     */
    placeholder: {
        type: PropType<String | String[]>;
        default: () => string[];
    };
    /**
     * @ignore
     */
    range: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Predefined date ranges the user can select from.
     */
    ranges: ObjectConstructor;
    /**
     * Toggle select mode between start and end date.
     */
    selectEndDate: BooleanConstructor;
    /**
     * Default icon or character character that separates two dates.
     */
    separator: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Size the component small or large.
     *
     * @values 'sm', 'lg'
     */
    size: {
        type: StringConstructor;
        required: false;
        validator: (value: string) => boolean;
    };
    /**
     * Initial selected date.
     */
    startDate: {
        type: (StringConstructor | DateConstructor)[];
    };
    /**
     * Provide an additional time selection by adding select boxes to choose times.
     */
    timepicker: BooleanConstructor;
    /**
     * Toggle visibility or set the content of today button.
     */
    todayButton: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    /**
     * Sets the color context of the today button to one of CoreUI’s themed colors.
     *
     * @values 'primary', 'secondary', 'success', 'danger', 'warning', 'info', 'dark', 'light'
     */
    todayButtonColor: {
        default: string;
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Size the today button small or large.
     *
     * @values 'sm', 'lg'
     */
    todayButtonSize: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Set the today button variant to an outlined button or a ghost button.
     *
     * @values 'ghost', 'outline'
     */
    todayButtonVariant: {
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Set length or format of day name.
     *
     * @type  number | 'long' | 'narrow' | 'short'
     */
    weekdayFormat: {
        type: (NumberConstructor | StringConstructor)[];
        default: number;
        validator: (value: string | number) => boolean;
    };
}>> & {
    onHide?: ((...args: any[]) => any) | undefined;
    onShow?: ((...args: any[]) => any) | undefined;
    "onStart-date-change"?: ((...args: any[]) => any) | undefined;
    "onEnd-date-change"?: ((...args: any[]) => any) | undefined;
}, {
    disabled: boolean;
    calendars: number;
    firstDayOfWeek: number;
    locale: string;
    navigation: boolean;
    range: boolean;
    selectEndDate: boolean;
    weekdayFormat: string | number;
    cancelButton: string | boolean;
    cancelButtonColor: string;
    cancelButtonSize: string;
    cancelButtonVariant: string;
    confirmButton: string | boolean;
    confirmButtonColor: string;
    confirmButtonSize: string;
    footer: boolean;
    cleaner: boolean;
    indicator: boolean;
    inputReadOnly: boolean;
    placeholder: String | String[];
    separator: boolean;
    timepicker: boolean;
    todayButton: string | boolean;
    todayButtonColor: string;
    todayButtonSize: string;
}>;
export { CDateRangePicker };
